==> digikamimageplugins_0.7.0.orig.tar.gz: digikamimageplugins-0.7.0/digikamimageplugins/despeckle/imageplugin_despeckle.cpp <==
/* ============================================================
 * File  : imageplugin_despeckle.h
 * Author: Gilles Caulier <caulier dot gilles at free.fr>
 * Date  : 2004-08-24
 * Description : 
 * 
 * Copyright 2004 by Gilles Caulier
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published bythe Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

// KDE includes.
  
#include <klocale.h>
#include <kgenericfactory.h>
#include <klibloader.h>
#include <kaction.h>
#include <kcursor.h>
#include <kdebug.h>

// Digikam includes.

#include <digikam/imageiface.h>

// Local includes.

#include "despeckle.h"
#include "imageplugin_despeckle.h"

K_EXPORT_COMPONENT_FACTORY( digikamimageplugin_despeckle,
                            KGenericFactory<ImagePlugin_Despeckle>("digikamimageplugin_despeckle"));

ImagePlugin_Despeckle::ImagePlugin_Despeckle(QObject *parent, const char*,
                                             const QStringList &)
                : Digikam::ImagePlugin(parent, "ImagePlugin_Despeckle")
{
    new KAction(i18n("Noise Reduction..."), 0, 
                this, SLOT(slotDespeckle()),
                actionCollection(), "imageplugin_despeckle");

    kdDebug() << "ImagePlugin_Despeckle plugin loaded" << endl;
}

ImagePlugin_Despeckle::~ImagePlugin_Despeckle()
{
}

QStringList ImagePlugin_Despeckle::guiDefinition() const
{
    QStringList guiDef;
    guiDef.append("MenuBar/Menu/Fi&x/Fix/Action/imageplugin_despeckle/ ");
    return guiDef;
}

void ImagePlugin_Despeckle::slotDespeckle()
{
    DigikamDespeckleFilterImagesPlugin::DespeckleDialog dlg(parentWidget());
    dlg.exec();
}


#include "imageplugin_despeckle.moc"

==> digikamimageplugins_0.7.2.orig.tar.gz: digikamimageplugins-0.7.2/digikamimageplugins/despeckle/imageplugin_despeckle.cpp <==
/* ============================================================
 * File  : imageplugin_despeckle.h
 * Author: Gilles Caulier <caulier dot gilles at free.fr>
 * Date  : 2004-08-24
 * Description : 
 * 
 * Copyright 2004 by Gilles Caulier
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

// KDE includes.
  
#include <klocale.h>
#include <kgenericfactory.h>
#include <klibloader.h>
#include <kaction.h>
#include <kcursor.h>
#include <kdebug.h>

// Local includes.

#include "despeckle.h"
#include "imageplugin_despeckle.h"

K_EXPORT_COMPONENT_FACTORY( digikamimageplugin_despeckle,
                            KGenericFactory<ImagePlugin_Despeckle>("digikamimageplugin_despeckle"));

ImagePlugin_Despeckle::ImagePlugin_Despeckle(QObject *parent, const char*,
                                             const QStringList &)
                     : Digikam::ImagePlugin(parent, "ImagePlugin_Despeckle")
{
    new KAction(i18n("Noise Reduction..."), "despeckle", 0, 
                this, SLOT(slotDespeckle()),
                actionCollection(), "imageplugin_despeckle");
                
    setXMLFile("digikamimageplugin_despeckle_ui.rc");                

    kdDebug() << "ImagePlugin_Despeckle plugin loaded" << endl;
}

ImagePlugin_Despeckle::~ImagePlugin_Despeckle()
{
}

void ImagePlugin_Despeckle::slotDespeckle()
{
    DigikamDespeckleFilterImagesPlugin::DespeckleDialog dlg(parentWidget());
    dlg.exec();
}


#include "imageplugin_despeckle.moc"
